@@ -7,6 +7,7 @@
 
 typedef struct _DBInfo		DBInfo;
 typedef struct _AppConfig	AppConfig;
+typedef struct _Options		Options;
 
 struct _DBInfo
 {
@@ -24,12 +25,27 @@ struct _AppConfig
 	gint res_limit;
 };
 
+struct _Options
+{
+	gchar *dbname;
+	gchar *hostname;
+	gushort port;
+	gchar *user;
+	gchar *pass;
+	gboolean no_remove;
+	gboolean recursive;
+	gboolean verbose;
+	gchar *mecab_encoding;
+	GSList *exclude_list;
+};
+
 gchar *sql_escape_str(DBInfo *conn, const gchar *str);
 gchar *get_wakachi_text(const gchar *str);
 
 gint parse_cmdline(gint argc, gchar *argv[],
 		   gchar **dbname, gchar **hostname, gushort *port,
 		   gchar **user, gchar **pass);
+gint parse_cmdline_options(gint argc, gchar *argv[], Options *options);
 gboolean cmdline_has_option(gint argc, gchar *argv[], const gchar *opt);
 
 gint read_config(AppConfig *config);
