@@ -1,5 +1,5 @@
 /* Sylph-Searcher - full-text search program for Sylpheed
- * Copyright (C) 2007 Sylpheed Development Team
+ * Copyright (C) 2007-2009 Sylpheed Development Team
  */
 
 #include "config.h"
@@ -26,9 +26,12 @@
 #  include <winreg.h>
 #  include <wchar.h>
 #  include <shlobj.h>
+#  include <fcntl.h>
 #endif
 
+#include "version.h"
 #include "common.h"
+#include "searcher-config.h"
 
 #define PG_CONN(dbinfo) ((PGconn *)dbinfo->dbdata)
 
@@ -775,6 +778,43 @@ static void config_dir_init(void)
 	g_free(path);
 }
 
+static void init_console(void)
+{
+#ifdef G_OS_WIN32
+	gint fd;
+	FILE *fp;
+	static gboolean init_console_done = FALSE;
+
+	if (init_console_done)
+		return;
+
+	if (!AllocConsole()) {
+		g_warning("AllocConsole() failed\n");
+		return;
+	}
+
+	fd = _open_osfhandle((glong)GetStdHandle(STD_OUTPUT_HANDLE), _O_TEXT);
+	_dup2(fd, 1);
+	fp = _fdopen(fd, "w");
+	*stdout = *fp;
+	setvbuf(stdout, NULL, _IONBF, 0);
+	fd = _open_osfhandle((glong)GetStdHandle(STD_ERROR_HANDLE), _O_TEXT);
+	_dup2(fd, 2);
+	fp = _fdopen(fd, "w");
+	*stderr = *fp;
+	setvbuf(stderr, NULL, _IONBF, 0);
+
+	init_console_done = TRUE;
+#endif
+}
+
+static void cleanup_console(void)
+{
+#ifdef G_OS_WIN32
+	FreeConsole();
+#endif
+}
+
 void alert_dialog(const gchar *title, const gchar *msg)
 {
 	GtkWidget *dialog;
@@ -789,6 +829,9 @@ void alert_dialog(const gchar *title, const gchar *msg)
 						 "%s", msg);
 #endif
 	gtk_window_present(GTK_WINDOW(ftsearch_window.window));
+	gtk_widget_show(dialog);
+	gtk_window_set_transient_for(GTK_WINDOW(dialog),
+				     GTK_WINDOW(ftsearch_window.window));
 	gtk_dialog_run(GTK_DIALOG(dialog));
 	gtk_widget_destroy(dialog);
 }
@@ -806,6 +849,8 @@ int main(int argc, char *argv[])
 	conf_ok = read_config(&config);
 
 	parse_cmdline(argc, argv, &dbname, &host, &port, &user, &pass);
+	if (cmdline_has_option(argc, argv, "--debug"))
+		init_console();
 
 	gtk_set_locale();
 	gtk_init(&argc, &argv);
@@ -825,8 +870,15 @@ int main(int argc, char *argv[])
 	if (port > 0)
 		config.port = port;
 
-	if (conf_ok < 0)
-		searcher_config(&config);
+	if (conf_ok < 0) {
+		if (!config.dbname)
+			config.dbname = g_strdup("sylph");
+#ifdef G_OS_WIN32
+		if (!port)
+			config.port = 25432;
+#endif
+		searcher_config(&config, GTK_WINDOW(ftsearch_window.window));
+	}
 
 	conn = db_connect(config.dbname, config.hostname, config.port,
 			  config.user, config.pass);
@@ -838,6 +890,7 @@ int main(int argc, char *argv[])
 
 	db_disconnect(conn);
 	//syl_cleanup();
+	cleanup_console();
 
 	return 0;
 }
@@ -894,7 +947,6 @@ static gchar *win32_get_app_path(void)
 static void row_activated(GtkTreeView *treeview, GtkTreePath *path,
 			  GtkTreeViewColumn *column, gpointer data)
 {
-	gulong sid = 0;
 	GtkTreeModel *model = GTK_TREE_MODEL(ftsearch_window.store);
 	GtkTreeIter iter;
 	gchar *folder_id;
@@ -1021,7 +1073,7 @@ static void paste_cb(void)
 
 static void settings_cb(void)
 {
-	if (searcher_config(&config)) {
+	if (searcher_config(&config, GTK_WINDOW(ftsearch_window.window))) {
 		db_disconnect(conn);
 		conn = db_connect(config.dbname, config.hostname, config.port,
 				  config.user, config.pass);
@@ -1066,7 +1118,7 @@ static void about_cb(void)
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 	label = gtk_label_new("version " VERSION);
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
-	label = gtk_label_new("Copyright (C) 2007 Sylpheed Development Team");
+	label = gtk_label_new("Copyright (C) 2007-2009 Sylpheed Development Team");
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 
 	g_signal_connect(G_OBJECT(dialog), "response", G_CALLBACK(response_cb),
