@@ -17,7 +17,7 @@ CREATE TABLE msginfo (
 	body_index TSVECTOR
 );
 
--- CREATE INDEX msginfo_msgid_index ON msginfo (hdr_msgid);
+CREATE INDEX msginfo_msg_date_index ON msginfo (msg_date);
 CREATE INDEX msginfo_body_index ON msginfo USING gin (body_index);
 
 -- CREATE TRIGGER msginfo_update BEFORE UPDATE OR INSERT ON msginfo
